@@ -98,8 +98,18 @@ def _cli_main(parser: argparse.ArgumentParser, args_list: List[str]):
         storage = AzureBlobStorage(cache_dir,
                                    config['data_azure_storage_container_uri'],
                                    config['data_azure_storage_path'])
-        storage.authenticate(generate_azure_account_sas(
-            config['data_azure_storage_connection_string']))
+
+        storage_connection = ""
+        if 'data_azure_storage_connection_string' in config:
+            storage_connection = config['data_azure_storage_connection_string']
+        elif args.storage_connection is not None:
+            storage_connection = args.storage_connection
+
+        if storage_connection is None or storage_connection == "":
+            print("Storage connection string must be provided in the configuration file or as --storage-connection option.")
+            parser.exit(_DEFAULT_ERROR)
+
+        storage.authenticate(generate_azure_account_sas(storage_connection))
 
     if not do_list and "link" in args.stage:
         if args.data_dir is None:
@@ -221,8 +231,13 @@ def _create_parser() -> argparse.ArgumentParser:
     parser.add_argument('--group_len', help='Maximum number of files in a listing file. Required for list stage.',
                         action='store', dest='group_len', default=1000)
 
-    parser.add_argument('--config', help='Configuration file. Required for cache stage.',
+    parser.add_argument('--config', help='Configuration file. Required for cache and list stages.',
                         action='store', dest='config_file', required=False)
+    
+    parser.add_argument('--storage-connection', 
+                        help='Storage connection string. Used with cache and list stages when is not in the configuration file.',
+                        action='store', dest='storage_connection', required=False)
+
     return parser
 
 
